@@ -2,7 +2,7 @@
 Estimation of fuselage geometry
 """
 #  This file is part of FAST-OAD : A framework for rapid Overall Aircraft Design
-#  Copyright (C) 2020  ONERA & ISAE-SUPAERO
+#  Copyright (C) 2021 ONERA & ISAE-SUPAERO
 #  FAST is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -13,6 +13,3 @@ Estimation of fuselage geometry
 #  GNU General Public License for more details.
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-from .compute_cnbeta_fuselage import ComputeCnBetaFuselage
-from .compute_fuselage import ComputeFuselageGeometryBasic, ComputeFuselageGeometryCabinSizing
